# run the file 
# r -f iris_data_manipulation.R

# Data Manipulation with R

# load the dataset
iris = read.csv('iris.csv', header = TRUE, sep=',')

# show the entire dataset
iris

# head of the dataset
head(iris)

# tail of the dataset
tail(head)

# visualize a summary of the data in the shell
str(iris)

# dimension
dim(iris)

# names
names(iris)

# attributes
attributes(iris)

# selection
# how many elements? length(x)
# ith element x[2] (i = 2)
# all but ith element x[-2] (i = 2)
# first k elements x[1:5] (k = 5)
# last k elements x[(length(x)-5):length(x)] (k = 5)
# specific elements. x[c(1,3,5)] (First, 3rd and 5th)
# all greater than some value x[x>3] (the value is 3)
# bigger than or less than some values x[ x< -2 | x > 2]
# which indices are largest which(x == max(x))

# select a column by index
iris[5]

# select everything except a column by index
iris[-5]

# select a column by name
iris$sepal.length

# vector length
length(iris$sepal.length)

# select a value
iris$sepal.length[5]

# comparison
iris$sepal.length[5] == 5
which(iris$sepal.length == 5)

# sort
sort(iris$petal.width)

# statistics
mean(iris$sepal.length)
sd(iris$sepal.length)
var(iris$sepal.length)
median(iris$sepal.length)
min(iris$sepal.length)
max(iris$sepal.length)

# summary statistics
summary(iris)

# frequency
table(iris$Species)

# correlation
cor(iris[-5])
cor.test(iris$sepal.length,iris$sepal.width,method='kendall')

# histograms
hist(iris$petal.length)
hist(iris$petal.length,breaks=c(1.0,3.0,4.5,4.0,6.9),main='Title',xlab='xlab',ylab='ylab',col='lightgreen',xlim=c(0,10),ylim=c(0, .30))
print(hist(iris$petal.length))

# histogram and line
x = hist(iris$petal.length)
lines(c(min(x$breaks),x$mids,max(x$breaks)),c(0,x$counts,0),type="l")

# boxplot
boxplot(iris)
boxplot(iris$petal.length,iris$petal.width)
boxplot(iris,notch=TRUE)
print(boxplot(iris$sepal.width))

# scatterplot
plot(iris) #scatter matrix
plot(iris$petal.width,iris$petal.length)
plot(iris$petal.width,iris$petal.length, pch=as.numeric(iris$Species))
plot(iris$petal.width,iris$petal.length)
identify(iris$petal.width,iris$petal.length)

# lineplot
plot(1:length(iris$petal.width),sort(iris$petal.width), type='o', col='blue')

# densityplot
plot(density(iris$sepal.length))

# piechart
pie(table(iris$Species))

# scatterplot3d
library(scatterplot3d)
scatterplot3d(iris$sepal.length, iris$sepal.width, iris$petal.length)

# stars
library(MASS)
stars(iris)

# outliers detection
library(outliers)
grubbs.test(iris$petal.width)

# missing values
x = c(3,2,NA,4,NA,1,NA,NA,5)
mean(x)
mean(x,na.rm=T)

# normalization
iris.norm <- iris
for (i in c(1:length(iris.norm))){
	if (!is.factor(iris.norm[,i])){
		attr.mean <- mean(iris.norm[,i])
		attr.sd <- sd(iris.norm[,i])
		iris.norm[,i] <- (iris.norm[,i]-attr.mean)/attr.sd
	}
}
iris.norm$sepal.length


